@@ -14,12 +14,15 @@ App::LXC::Container - configure, create and run LXC application containers
 
 =head1 ABSTRACT
 
-B<Currently this module is unfinished work in progress!  It is only uploaded
-to test the development processes and see how the tests run and fail on the
-various different platforms.  In the first versions it also only supports
+B<Currently this module is an alpha release.  It currently only supports
 Debian (and maybe Ubuntu and some other derivates) using Pipewire or
 Pulseaudio as audio system and X11 as windowing system.  Also see KNOWN BUGS
 below!>
+Other distributions derived from Debian using Pipewire / Pulseaudio and X11
+should be easy to add.  For RPM based distributions I've already some ideas
+how they could be added.  All those cases need some collaboration with users
+using them though.  Other distributions need some more work, but are welcome
+nonetheless.
 
 App::LXC::Container provides a toolbox to configure, create and run one or
 more applications inside of simple and secure LXC (L<Linux
@@ -374,7 +377,7 @@ use warnings 'once';
 
 use File::Path 'make_path';
 
-our $VERSION = "0.27";
+our $VERSION = "0.28";
 
 # TODO: Caller dependent module usage to only include UI::Various for setup
 # and corresponding tests.  Is there a better approach?
